import React, {ReactElement} from 'react';
import {render, RenderOptions} from '@testing-library/react';

const AllTheProviders = ({children}: {children: React.ReactNode}) => {
  return <React.Fragment>{children}</React.Fragment>;
};

const customRender = (ui: ReactElement, options?: Omit<RenderOptions, 'wrapper'>) =>
  render(ui, {wrapper: AllTheProviders, ...options});

const mockedMethods = ['log', 'warn', 'error'];
export const {originalConsoleFuncs, consoleMessages} = mockedMethods.reduce(
  (acc: any, method: any) => {
    acc.originalConsoleFuncs[method] = console[method].bind(console);
    acc.consoleMessages[method] = [];

    return acc;
  },
  {
    consoleMessages: {},
    originalConsoleFuncs: {},
  }
);

export const clearConsole = () =>
  mockedMethods.forEach((method) => {
    consoleMessages[method] = [];
  });

export const mockConsole = (callOriginals?: boolean) => {
  const createMockConsoleFunc = (method: any) => {
    console[method] = (...args: any[]) => {
      consoleMessages[method].push(args);
      if (callOriginals) return originalConsoleFuncs[method](...args);
    };
  };

  const deleteMockConsoleFunc = (method: any) => {
    console[method] = originalConsoleFuncs[method];
    consoleMessages[method] = [];
  };

  beforeEach(() => {
    mockedMethods.forEach((method: any) => {
      createMockConsoleFunc(method);
    });
  });

  afterEach(() => {
    mockedMethods.forEach((method: any) => {
      deleteMockConsoleFunc(method);
    });
  });
};

export * from '@testing-library/react';
export {customRender as render};
